==> calligra_2.8.1-1.orig.tar.xz: calligra-2.8.1/sheets/part/commands/PageLayoutCommand.cpp <==
/* This file is part of the KDE project
   Copyright 2004 Ariya Hidayat <ariya@kde.org>
   Copyright 2004 Laurent Montel <montel@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

// Local
#include "PageLayoutCommand.h"

#include "Sheet.h"

using namespace Calligra::Sheets;

// ----- PageLayoutCommand -----

PageLayoutCommand::PageLayoutCommand(Sheet* sheet, const PrintSettings& settings, KUndo2Command* parent)
        : KUndo2Command(parent)
        , m_sheet(sheet)
        , m_settings(settings)
{
    setText(i18nc("(qtundo-format)", "Set Page Layout"));
}

void PageLayoutCommand::redo()
{
    // Store the old settings.
    PrintSettings settings = *m_sheet->printSettings();
    // Set the new ones.
    m_sheet->setPrintSettings(m_settings);
    // Store the old settings permanently.
    m_settings = settings;
}

void PageLayoutCommand::undo()
{
    // Exchange the settings.
    redo();
}

==> calligra_3.2.1+dfsg.orig.tar.xz: calligra-3.2.1/sheets/part/commands/PageLayoutCommand.cpp <==
/* This file is part of the KDE project
   Copyright 2004 Ariya Hidayat <ariya@kde.org>
   Copyright 2004 Laurent Montel <montel@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

// Local
#include "PageLayoutCommand.h"

#include "Sheet.h"

using namespace Calligra::Sheets;

// ----- PageLayoutCommand -----

PageLayoutCommand::PageLayoutCommand(Sheet* sheet, const PrintSettings& settings, KUndo2Command* parent)
        : KUndo2Command(parent)
        , m_sheet(sheet)
        , m_settings(settings)
{
    setText(kundo2_i18n("Set Page Layout"));
}

void PageLayoutCommand::redo()
{
    // Store the old settings.
    PrintSettings settings = *m_sheet->printSettings();
    // Set the new ones.
    m_sheet->setPrintSettings(m_settings);
    // Store the old settings permanently.
    m_settings = settings;
}

void PageLayoutCommand::undo()
{
    // Exchange the settings.
    redo();
}
